==> v2.28.tar.gz: privacyguides.org/docs/index.en.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
---
<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, our right to privacy hasn't always been upheld. In several dictatorships, it still isn't. Generations before ours fought for our right to privacy. ==Privacy is a human right, inherent to all of us,== that we are entitled to (without discrimination).

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to protect. Privacy is something that makes you human.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## What should I do?

##### First, you need to make a plan.

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and, by thinking ahead, you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins by understanding the unique threats you face, and how you can mitigate them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## We need you! Here's how to get involved:

It's important for a website like Privacy Guides to always stay up-to-date. We need our audience to keep an eye on software updates for the applications listed on our site and follow recent news about providers that we recommend. It's hard to keep up with the fast pace of the internet, but we try our best. If you spot an error, think a provider should not be listed, notice a qualified provider is missing, believe a browser plugin is no longer the best choice, or uncover any other issue, please let us know.

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-discourse: Join our forum](https://discuss.privacyguides.org/)
- [:simple-mastodon: Follow us on Mastodon](https://mastodon.social/@privacyguides){ rel=me }
- [:material-book-edit: Contribute to this website](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: Chat with us on Matrix](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: Learn more about us](about/index.md)
- [:material-hand-coin-outline: Support the project](about/donate.md)

</div>
</div>

==> v3.2.tar.gz: privacyguides.org/docs/index.en.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
---
<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, our right to privacy hasn't always been upheld. In several dictatorships, it still isn't. Generations before ours fought for our right to privacy. ==Privacy is a human right, inherent to all of us,== that we are entitled to (without discrimination).

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to protect. Privacy is something that makes us human.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## What should I do?

##### First, you need to make a plan

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and, by thinking ahead, you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins by understanding the unique threats you face, and how you can mitigate them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## We need you! Here's how to get involved:

It's important for a website like Privacy Guides to always stay up-to-date. We need our audience to keep an eye on software updates for the applications listed on our site and follow recent news about providers that we recommend. It's hard to keep up with the fast pace of the internet, but we try our best. If you spot an error, think a provider should not be listed, notice a qualified provider is missing, believe a browser plugin is no longer the best choice, or uncover any other issue, please let us know.

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-discourse: Join our forum](https://discuss.privacyguides.net/)
- [:simple-mastodon: Follow us on Mastodon](https://mastodon.neat.computer/@privacyguides){ rel=me }
- [:material-book-edit: Contribute to this website](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: Chat with us on Matrix](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: Learn more about us](about/index.md)
- [:material-hand-coin-outline: Support the project](about/donate.md)

</div>
</div>
